+++
title = "Sinara core"
weight = 2
template = "page.html"

[extra]
title = "Sinara hardware"
+++


{% layout_text_img(src="images/sinara-hardware@2x.png", popup="images/origin/sinara_hardware.jpg", alt="", textleft=true, shadow=false) %}

The first ARTIQ core devices used hardware built in-house by physicists (based on a Xilinx KC705 development board with custom FMC cards). To improve the quality, features and scalability of ARTIQ systems, we have been developing the Sinara device family. It provides turnkey control hardware that is reproducible, open, flexible, modular, well-tested, and well-supported by the ARTIQ control software.

The Sinara hardware is in active development, and the latest information is available <a href="https://github.com/sinara-hw" target="_blank" rel="noopener noreferrer">on the wiki of each project's page</a>. Most of the hardware engineering is done at the <a href="http://www.ise.pw.edu.pl/" target="_blank" rel="noopener noreferrer">Institute for Electronics Systems</a> at the Warsaw University of Technology.

Kasli and EEMs can be ordered now. We can deliver a rack-mountable crate that contains all the cards, is fully tested, and is ready to be connected to your experiment and computer network. Contact sales@m-\*\*\*s.hk with your requirements and we will establish a quote.

{% end %}



{% layout_text_img(src="images/kasli@2x.png", popup="images/origin/kasli.jpg", alt="", shadow=false) %}

##### Sinara 1123 Carrier "Kasli"

One of the main devices in the Sinara family is the 1123 Carrier (codenamed Kasli). It contains an Artix-7 100T FPGA, DDR3 SDRAM, three SFP connectors, and can control up to 8 daughtercards (Eurocard Extension Module, EEM) or 12 with the "backplane adapter". The Kasli can act as a stand-alone core device, or as a DRTIO satellite or repeater. The Kasli and its EEMs are installed in one Eurocard 3U chassis. One SFP connector is used for a Gigabit Ethernet connection to your computer network.

<a href="https://github.com/sinara-hw/Kasli/wiki" target="_blank" rel="noopener noreferrer">More information</a>

{% end %}



{% layout_text_img(src="images/isolated-ttl@2x.png", popup="images/origin/dio.jpg", alt="", textleft=true, shadow=false) %}

##### Sinara 2118/2128/2138 TTL cards

For simple TTL signals, we offer I/O cards in the EEM form factor with 8 channels over BNC (2118), SMA (2128) or MCX (2138) connectors. The IOs are divided into two banks of 4, with per-bank ground isolation. The direction (input/output) and termination (high-Z/50R) is selectable on a per-channel basis via I2C or on-board switches. The open circuit voltage of outputs is 5V, and outputs can supply a valid TTL level into 50&#8486; and tolerate an indefinite short circuit to ground.

More information: <a href="https://github.com/sinara-hw/DIO_BNC/wiki" target="_blank" rel="noopener noreferrer">BNC card</a> <a href="https://github.com/sinara-hw/DIO_SMA/wiki" target="_blank" rel="noopener noreferrer">SMA card</a>

{% end %}



{% layout_text_img(src="images/LVDS@2x.png", popup="images/origin/dio_rj45.jpg", alt="", shadow=false) %}

##### Sinara 2245 LVDS TTL card

For high-density or faster signals, the Sinara 2245 is an extension module supplying 16 LVDS pairs via 4 front-panel RJ45 connectors.
Each RJ45 supplies 4 LVDS DIOs. The direction (input/output) is individually selectable for each signal via on-board switches. Outputs are intended to drive 100&#8486; loads (LVDS is short-circuit protected), inputs are 100&#8486; terminated. The connectors dedicate all 8 pins to LVDS signals, ground is on the connector shield so only shielded Ethernet cat 6 shielded cables are allowed.

<a href="https://github.com/sinara-hw/DIO_RJ45/wiki" target="_blank" rel="noopener noreferrer">More information</a>

{% end %}



{% layout_text_img(src="images/Banker-TTL-1@2x.png", popup="images/origin/banker1.jpg", alt="", textleft=true, shadow=false) %}

##### Sinara 3128 TTL I/O expander "Banker"

Banker is a versatile 128-channel TTL GPIO module. It has flexible connectivity and contains a small Lattice iCE40 FPGA, supported by Yosys and IceStorm.
Interfaces include:

- 8 x 8 channel IDC connectors, compatible with BNC-IDC and SMA-IDC.
- 2 x 32 channel VHDCI connectors.
- 2 downstream EEM connectors that enable daisy-chain connection of several Banker modules.
- front panel DC Jack and rear side Molex supply connector.

{% end %}



{% layout_text_img(src="images/Banker-TTL-2@2x.png", popup="images/origin/banker2.jpg", alt="", textleft=true, shadow=false) %}

All outputs can be configured either as 3.3 or 5V. They can drive 50R load when set to 5V. FPGA can is configured from on-board FLASH. FLASH can be updated over I2C or with the on-board SPI connector.

The VHDCI connections can be used to interface with either non-buffered or buffered remote boards that distribute signals to neighboring modules. These modules can be assembled together and placed in COTS enclosures. The enclosures fit onto the low-cost and simple DIN rail standard.

There are several DIN-rail compatible modules for use with Banker. They are interconnected using edge connectors and can be configured as mix of 4 modules of following type:

- 8 channel D-SUB
- 8 channel BNC
- 8 channel SMA
- 8 channel screw terminal

**Note:** While Banker can be used currently if you program the FPGA yourself, turn-key support from within ARTIQ is currently not available or funded. Contact us if you would like to sponsor this project.

<a href="https://github.com/sinara-hw/Banker/wiki" target="_blank" rel="noopener noreferrer">More information</a>

{% end %}



{% layout_text_img(src="images/Urukul-DDS@2x.png", popup="images/origin/urukul.jpg", alt="", shadow=false) %}

##### Sinara 4410/4412 DDS "Urukul"

Urukul is a 4 channel DDS-based frequency synthesizer for the EEM form factor. It provides sub-Hz frequency resolution, controlled phase steps, and accurate output amplitude control. We offer it in two variants, with either the AD9910 (Sinara 4410) or the AD9912 (Sinara 4412) chip.

With the SU-Servo feature of ARTIQ, the 4410 DDS (which has fine amplitude control, unlike the 4412) can be used in combination with the 5108 Sampler to form a laser intensity servo. In this application, the Urukul card drives AOMs and photodiodes are connected to Sampler to monitor laser intensities. When ordering your system, specify that you want SU-Servo integrated into the gateware.

In regular mode, various DDS features are supported, including frequency, phase and amplitude control, and AD9910 RAM mode. See the ARTIQ manual for more details.

<a href="https://github.com/sinara-hw/Urukul/wiki" target="_blank" rel="noopener noreferrer">More information</a>

{% end %}



{% layout_text_img(src="images/Mirny-Synth@2x.png", popup="images/origin/mirny.jpg", alt="", textleft=true, shadow=false) %}

##### Sinara 4456 synthesizer "Mirny"

Mirny is a 4 channel wide-band PLL/VCO-based microwave frequency synthesiser.

Like the Urukul DDS but with a VCO/PLL (ADF5356) as the synthesizer and options for frequency double/tripler and analog frontend mezzanines.

Comparing Mirny to Urukul:

- Much larger frequency range (53 MHz to >4 GHz vs. ~1 MHz to 500 MHz in the first Nyquist zone for Urukul). Up to 13.6 GHz when using the mezzanine.
- Much higher frequency resolution.
- Lower jitter and phase noise.
- No linear high resolution output amplitude setting (c.f. AD9910 ASF).
- No deterministic phase control, no coherent or absolute phase changes.
- Large frequency changes are not "agile" (take a few ms) and do not have high timing resolution; small frequency changes (<10 kHz) can still be made rapidly.
- RF switch changes or attenuator changes still benefit from high timing resolution through the EEM connector.

<a href="https://github.com/sinara-hw/mirny/wiki" target="_blank" rel="noopener noreferrer">More information</a>

{% end %}



{% layout_text_img(src="images/Zotino-DAC@2x.png", popup="images/origin/zotino.jpg", alt="", shadow=false) %}

##### Sinara 5432 DAC "Zotino"

Zotino is a 32-channel, 16-bit DAC EEM with an update rate of 1MSPS (divided between the channels). It was designed for low noise and good stability.

Zotino connects the 32 channels to both (a) a HD68 connector on its front panel and (b) to four IDC connectors on the board. Each IDC connection with 8 channels can be broken out to BNC or SMA using BNC-IDC or SMA-IDC respectively.

It is also possible to connect the Zotino using a HD68 cable to an external crate containing BNC-IDC or SMA-IDC cards.

<a href="https://github.com/sinara-hw/Zotino/wiki" target="_blank" rel="noopener noreferrer">More information</a>

##### Sinara 5632 DAC "Fastino"

Fastino is a higher-speed version of Zotino. It also has 32 16-bit channels, but they all can be updated at 2Msps simultaneously (1Gb/s data).

Note that reaching this maximum hardware speed requires gateware acceleration; naively pushing samples one by one from a software ARTIQ-Python kernel results in a much lower update rate.

<a href="https://github.com/sinara-hw/Fastino/wiki" target="_blank" rel="noopener noreferrer">More information</a>

{% end %}



{% layout_text_img(src="images/Sampler-ADC@2x.png", popup="images/origin/sampler.jpg", alt="", textleft=true, shadow=false) %}

##### Sinara 5108 Sampler

The Sinara 5108 is an 8-channel, 16-bit ADC EEM with an update rate of up to 1.5MSPS (all channels simultaneously). It has low-noise differential front end with a digitally programmable gain, providing full-scale input ranges between +-10mV (G=1000) and +-10V (G=1).

In SU-Servo mode, the 5108 Sampler can be used in combination with the 4410 DDS to form a laser intensity servo. Otherwise, in regular mode, single sample values can be read out by ARTIQ kernels (due to CPU overhead, the actual sample rate in regular mode is reduced).

<a href="https://github.com/sinara-hw/Sampler/wiki" target="_blank" rel="noopener noreferrer">More information</a>

Note that update rate specification on this page is for the hardware only; ARTIQ kernel and RTIO overhead make the effective sample rate lower. Typically, only with gateware (e.g. SU-Servo) can the maximum bandwidth be achieved. SU-Servo is part of the regular ARTIQ firmware; development of other gateware can be purchased separately.

{% end %}



{% layout_text_img(src="images/Grabber-camera-interface@2x.png", popup="images/origin/grabber.jpg", alt="", shadow=false) %}

##### Sinara 6302 Grabber

The Sinara 6302 Grabber allows the connection of certain scientific (EM)CCD cameras port to the core FPGA. Those cameras have a Camera Link interface.

In the FPGA, frame data streamed through "ROI engines". Each ROI engine gates on one rectangular pixel region and accumulates pixel values for each frame. The ROI engines operate independently and can be overlapping. After the frame, the accumulated value is pushed as an RTIO input event. Regions of interest (ROI) can be configured at runtime, and are defined with the computer.

<a href="https://github.com/sinara-hw/Grabber/wiki" target="_blank" rel="noopener noreferrer">More information</a>

{% end %}



{% layout_text_img(src="images/clocker@2x.png", popup="images/origin/clocker.jpg", alt="", textleft=true, shadow=false) %}

##### Sinara 7210 Clocker

The Sinara 7210 is a low-noise clock distribution module that can be used to distribute low jitter clock signal among 3U boards. 2 inputs, 10 outputs including 4 SMAs, frequency up to 1GHz, low jitter <100fs RMS.

<a href="https://github.com/sinara-hw/Clocker/wiki" target="_blank" rel="noopener noreferrer">More information</a>

{% end %}



{{ layout_separator_empty() }}



{{ layout_separator(separator_title="Purchasing Sinara hardware", css="col-12 text-center mt-2 mb-2 mb-lg-5") }}



{% layout_centered_content(min_width=true, css="row d-flex align-items-center mt-5") %}

##### Kasli and EEMs can be ordered now

We can deliver a rack-mountable crate that contains all the cards, is fully tested, and is ready to be connected to your experiment and computer network.

Contact sales@m-\*\*\*s.hk with your requirements and we will establish a quote.

{% end %}


{{ layout_separator_empty(inverted="true") }}


{% layout_centered_content(min_width=true) %}

##### Metlino and Sayma

For more demanding experiments, we have been developing the Metlino and Sayma system. One Sayma card includes 8 channels of 2.4GSPS 16-bit DACs and a Kintex Ultrascale FPGA. The FPGA synthesizes waveforms for the DACs and our gateware supports two-tone direct digital synthesis and shaping of the waveform parameters with splines.

Multiple Sayma cards can be installed in a MicroTCA chassis together with one Metlino master. Clock synchronization will be supported.

{% end %}
