+++
title = "Migen"
weight = 1
template = "page.html"

[extra]
logo = "images/migen@2x.png"
logo_size = 125
title = "Migen"
+++


{% layout_centered_content() %}
##### Migen is a Python-based tool that automates further the VLSI design process.
{% end %}


<div class="row d-flex align-items-center mt-5 mb-5">

{% layout_div(css="col-12 col-md-6") %}

Despite being faster than schematics entry, hardware design with Verilog and VHDL remains tedious and inefficient for several reasons. The event-driven model introduces issues and manual coding that are unnecessary for synchronous circuits, which represent the lion's share of today's logic designs. Counter-intuitive arithmetic rules result in steeper learning curves and provide a fertile ground for subtle bugs in designs. Finally, support for procedural generation of logic (metaprogramming) through "generate" statements is very limited and restricts the ways code can be made generic, reused and organized.

{% end %}

{% layout_div(css="col-12 col-md-6") %}

To address those issues, we have developed the Migen FHDL library that replaces the event-driven paradigm with the notions of combinatorial and synchronous statements, has arithmetic rules that make integers always behave like mathematical integers, and most importantly allows the design's logic to be constructed by a Python program. This last point enables hardware designers to take advantage of the richness of the Python language - object oriented programming, function parameters, generators, operator overloading, libraries, etc. - to build well organized, reusable and elegant designs.

{% end %}

</div>


{% layout_centered_content(min_width=true) %}

Other Migen libraries are built on FHDL and provide various tools such as a system-on-chip interconnect infrastructure, a dataflow programming system, a more traditional high-level synthesizer that compiles Python routines into state machines with datapaths, and a simulator that allows test benches to be written in Python.

Migen is the foundation for MiSoC.

{% end %}


{% layout_centered_content(min_width=true, force_left=true, bg="background-image: url(/images/stripe.svg); background-repeat: no-repeat; background-size: auto 100%; padding-left: 40px;") %}

##### More...

You can find the Migen source <a href="http://github.com/m-labs/migen" target="_blank" rel="noopener noreferrer">here</a>, released under the permissive BSD license.

**Documentation**

- <a href="https://m-labs.hk/migen/manual/" target="_blank" rel="noopener noreferrer">User guide
- <a href="/docs/migen-tutorial.pdf" target="_blank" rel="noopener noreferrer">Tutorial</a> (outdated - in particular, the simulator has been rewritten and no longer uses Icarus)
- <a href="https://www.wdj-consulting.com/blog/migen-port.html" target="_blank" rel="noopener noreferrer">Tutorial "Porting a New Board To Migen"</a> by cr1901
- <a href="https://lab.whitequark.org/notes/2016-10-18/implementing-an-uart-in-verilog-and-migen/" target="_blank" rel="noopener noreferrer">"Implementing a UART in Verilog and Migen"</a> by whitequark
- <a href="https://lab.whitequark.org/notes/2016-10-19/implementing-a-simple-soc-in-migen/" target="_blank" rel="noopener noreferrer">"Implementing a simple SoC in Migen"</a> by whitequark
- <a href="http://blog.lambdaconcept.com/doku.php?id=migen:tutorial" target="_blank" rel="noopener noreferrer">Migen Step by Step Tutorial</a> by LambdaConcept

{% end %}



{% layout_text_img(src="images/side-graphic-min.png", alt="", textleft=true, shadow=false) %}

##### MiSoC

Built on Migen, MiSoC provides a high performance, flexible and lightweight solution to build system-on-chips for various applications.


- CPU options:
  - LatticeMico32, modified to include an optional MMU (experimental).
  - mor1kx, a better OpenRISC implementation.
- Memory controller supports SDR, DDR, LPDDR, DDR2 and DDR3.
- Provided peripherals: UART, GPIO, timer, GPIO, NOR flash controller, SPI flash controller, Ethernet MAC, and more.
- High performance: on Spartan-6, 83MHz system clock frequencies, 10+Gbps DDR SDRAM bandwidth, 1080p 32bpp framebuffer, etc.
- Low resource usage: basic implementation fits easily in Spartan-6 LX9.
- Portable and easy to customize thanks to Python- and Migen-based architecture.
- Design new peripherals using Migen and benefit from automatic CSR maps and logic, simplified DMAs, etc.
- Possibility to encapsulate legacy Verilog/VHDL code.

{% end %}
