+++
title = "SolveSpace"
weight = 1
template = "page-solvespace.html"

[extra]
layout_css = "col-12 col-md-10 mx-auto"
+++


{% div() %}
<script src="/js/hammer-2.0.8.js"></script>
<script src="/js/three-r76.js"></script>
<script src="/js/SolveSpaceControls.js"></script>
{% end %}



{% layout_centered_simple() %}
##### What is SolveSpace?
{% end %}

<a href="http://solvespace.com/" target="_blank" rel="noopener noreferrer">SolveSpace</a> is a libre and open-source parametric computer-aided design application that uses a NURBS geometric kernel, allowing it to represent curved surfaces exactly. It was originally released by <a href="http://cq.cx/" target="_blank" rel="noopener noreferrer">Jonathan Westhues</a> under the GPLv3 license and is now further developed at M-Labs.



{% layout_centered_simple(css="mt-5") %}
##### What can be done with SolveSpace?
{% end %}

SolveSpace is primarily useful for mechanical design. At M-Labs, we use it to design vacuum chambers as well as custom fittings and fixtures. The models can then be exported as STEP or PDF with dimensions and sent to a machine shop for manufacturing.



{% layout_centered_simple(css="mt-5") %}
**Fittings and adapters**
{% end %}

Of course, most vacuum chambers would have some standard flanges. These can be easily modelled using a single sketch and a lathe operation:



{% layout_treejs(two=true, css="row d-flex align-items-center mt-5 mb-1") %}
<img class="img-fluid kf25" src="/images/kf25-section.png" width="400" height="100%">

<div id="kf25"></div>
{% end %}

*(The illustration on the right is "live"; it can be panned, rotated and scaled.)*



In a similar way, an NW160 viewport and an adapter with an NW160 flange, a KF40, two KF25 and two KF16 ports were designed:

{% layout_treejs(two=true) %}
<div id="viewport"></div>
<div id="multiport"></div>
{% end %}



{% layout_centered_simple(css="mt-5") %}
**A vacuum chamber**
{% end %}

The fittings above were designed to be used with a cylindrical vacuum chamber, 200mm long with two NW160 flanges, two KF40 and one KF25 ports:

{% layout_treejs() %}
<div id="chamber"></div>
{% end %}



{% layout_centered_simple(css="mt-5") %}
**Cryocooler refilling fixture**
{% end %}

To repair a broken Ricor K526S crycooler, it was necessary to disassemble it, which of course meant it was depressurized. To evacuate it and eventually refill with helium, a special fixture was designed, as the cryocooler's filling port is just a hole in the case with a set screw. Further, an adapter that allows to insert the cold head into a vacuum system via a KF25 port was also designed.

First, the cryocooler and its cold head were modelled to verify fits:

{% layout_treejs(two=true) %}
<div id="k526s-body"></div>
<div id="k526s-head"></div>
{% end %}



Then, a fixture was designed, shown below with a cutout (blue). It consists of a bracket, a piston case that screws into the bracket (the thread is not modelled), a piston with a retaining screw, a retaining washer, a Swagelok fitting attached to the orange port (not modelled), and a few compression gaskets (also not modelled). The bracket and the piston case hold the cryocooler The retaining washer prevents the piston from being ejected by high pressure helium and, conversely, together with another washer prevents the piston from being sucked in and blocking the gas flow during evacuation.

{% layout_treejs() %}
<div id="k526s-fixture"></div>
{% end %}



The KF25 adapter for the cold head is a much simpler device:

{% layout_treejs(two=true) %}
<div id="k526s-adapter"></div>
<div id="k526s-adapter-assy"></div>
{% end %}



{% layout_centered_content(css="row d-flex align-items-center mt-5 mb-5 pt-5") %}
##### Ongoing development by M-Labs
{% end %}

As originally released, SolveSpace was far ahead almost every other FLOSS CAD by virtue of its parametric nature, exact internal representation of curves and a codebase easy to work with. (The only other FLOSS parametric CAD that uses a NURBS representation, including NURBS booleans, is FreeCAD.) While it was already suitable for practical work, it had a much greater unrealized potential.

Thus, M-Labs has developed many additional features:

- Native Linux (GTK) and OS X ports;
- stippling as well as <a href="https://m-labs.hk/solvespace/images/hiddenline.gif" target="_blank" rel="noopener noreferrer">outline and hidden line</a> styling in preparation for export of shop drawings according to ISO or another standard;
- WebGL export using Three.js, which is how the interactive models on this page work;
- DXF export that preserves the ability to edit the drawing afterwards, by mapping parametric constraints to DXF dimensions and grouping the lines;
- DXF import that automatically infers (some) constraints, such as horizontal/vertical, point-coincident, linear and angular dimensions from DXF geometry and dimensions;
- internationalization;
- and many other minor ones.
